pub struct StorageSchemaEntries {
pub types: Vec<Value>,
pub mutations: Vec<Value>,
pub queries: Vec<Value>,
}Expand description
All generated schema entries for a set of storage buckets.
Fields
types: Vec<Value>Type definitions for inclusion in the compiled schema types array.
mutations: Vec<Value>Mutation definitions for inclusion in the compiled schema mutations array.
queries: Vec<Value>Query definitions for inclusion in the compiled schema queries array.